@@ -56,12 +56,9 @@ meta_ui_init (int *argc, char ***argv)
 }
 
 Display*
-meta_ui_get_display (const char *name)
+meta_ui_get_display (void)
 {
-  if (name == NULL)
-    return gdk_display;
-  else
-    return NULL;
+  return gdk_display;
 }
 
 typedef struct _EventFunc EventFunc;
@@ -219,6 +216,9 @@ meta_ui_create_frame_window (MetaUI *ui,
   attrs.wmclass_class = NULL;
   attrs.override_redirect = FALSE;
 
+  attrs.width  = width;
+  attrs.height = height;
+
   attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
 
   window =
@@ -785,6 +785,43 @@ meta_ui_parse_accelerator (const char          *accel,
   return TRUE;
 }
 
+/* Caller responsible for freeing return string of meta_ui_accelerator_name! */
+gchar*
+meta_ui_accelerator_name  (unsigned int        keysym,
+                           MetaVirtualModifier mask)
+{
+  EggVirtualModifierType mods = 0;
+        
+  if (keysym == 0 && mask == 0)
+    {
+      return strdup ("disabled");
+    }
+
+  if (mask & META_VIRTUAL_SHIFT_MASK)
+    mods |= EGG_VIRTUAL_SHIFT_MASK;
+  if (mask & META_VIRTUAL_CONTROL_MASK)
+    mods |= EGG_VIRTUAL_CONTROL_MASK;
+  if (mask & META_VIRTUAL_ALT_MASK)
+    mods |= EGG_VIRTUAL_ALT_MASK;
+  if (mask & META_VIRTUAL_MOD2_MASK)
+    mods |= EGG_VIRTUAL_MOD2_MASK;
+  if (mask & META_VIRTUAL_MOD3_MASK)
+    mods |= EGG_VIRTUAL_MOD3_MASK;
+  if (mask & META_VIRTUAL_MOD4_MASK)
+    mods |= EGG_VIRTUAL_MOD4_MASK;
+  if (mask & META_VIRTUAL_MOD5_MASK)
+    mods |= EGG_VIRTUAL_MOD5_MASK;
+  if (mask & META_VIRTUAL_SUPER_MASK)
+    mods |= EGG_VIRTUAL_SUPER_MASK;
+  if (mask & META_VIRTUAL_HYPER_MASK)
+    mods |= EGG_VIRTUAL_HYPER_MASK;
+  if (mask & META_VIRTUAL_META_MASK)
+    mods |= EGG_VIRTUAL_META_MASK;
+
+  return egg_virtual_accelerator_name (keysym, mods);
+
+}
+
 gboolean
 meta_ui_parse_modifier (const char          *accel,
                         MetaVirtualModifier *mask)
@@ -890,20 +927,6 @@ meta_stock_icons_init (void)
   g_object_unref (G_OBJECT (factory));
 }
 
-int
-meta_ui_get_double_click_timeout (MetaUI *ui)
-{
-  GtkSettings *settings;
-  int timeout;
-
-  settings = gtk_widget_get_settings (GTK_WIDGET (ui->frames));
-
-  timeout = 250;
-  g_object_get (G_OBJECT (settings), "gtk-double-click-time", &timeout, NULL);
-
-  return timeout;
-}
-
 int
 meta_ui_get_drag_threshold (MetaUI *ui)
 {
